@@ -1,10 +1,5 @@
 package Perinci::To::Doc::Role::Section::AddTextLines;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-31'; # DATE
-our $DIST = 'Perinci-To-Doc'; # DIST
-our $VERSION = '0.878'; # VERSION
-
 use 5.010;
 use Log::ger;
 use Moo::Role;
@@ -14,6 +9,11 @@ requires 'doc_indent_level';
 requires 'doc_indent_str';
 has doc_wrap => (is => 'rw', default => sub {1});
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-05-14'; # DATE
+our $DIST = 'Perinci-To-Doc'; # DIST
+our $VERSION = '0.879'; # VERSION
+
 sub add_doc_lines {
     my $self = shift;
     my $opts;
@@ -114,7 +114,7 @@ Perinci::To::Doc::Role::Section::AddTextLines - Provide add_doc_lines() to add t
 
 =head1 VERSION
 
-This document describes version 0.878 of Perinci::To::Doc::Role::Section::AddTextLines (from Perl distribution Perinci-To-Doc), released on 2021-05-31.
+This document describes version 0.879 of Perinci::To::Doc::Role::Section::AddTextLines (from Perl distribution Perinci-To-Doc), released on 2022-05-14.
 
 =head1 DESCRIPTION
 
@@ -170,14 +170,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-To-Doc>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci::To::Doc::Role::Section>
@@ -186,11 +178,36 @@ L<Perinci::To::Doc::Role::Section>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-To-Doc>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
